@@ -48,9 +48,6 @@ from bitmovin_api_sdk.models.akamai_msl_version import AkamaiMslVersion
 from bitmovin_api_sdk.models.akamai_net_storage_input import AkamaiNetStorageInput
 from bitmovin_api_sdk.models.akamai_net_storage_output import AkamaiNetStorageOutput
 from bitmovin_api_sdk.models.analytics_abstract_filter import AnalyticsAbstractFilter
-from bitmovin_api_sdk.models.analytics_alerting_notification import AnalyticsAlertingNotification
-from bitmovin_api_sdk.models.analytics_alerting_rule import AnalyticsAlertingRule
-from bitmovin_api_sdk.models.analytics_alerting_webhook import AnalyticsAlertingWebhook
 from bitmovin_api_sdk.models.analytics_attribute import AnalyticsAttribute
 from bitmovin_api_sdk.models.analytics_avg_concurrent_viewers_response import AnalyticsAvgConcurrentViewersResponse
 from bitmovin_api_sdk.models.analytics_avg_dropped_frames_response import AnalyticsAvgDroppedFramesResponse
@@ -70,7 +67,6 @@ from bitmovin_api_sdk.models.analytics_impression_list_item import AnalyticsImpr
 from bitmovin_api_sdk.models.analytics_impressions_query import AnalyticsImpressionsQuery
 from bitmovin_api_sdk.models.analytics_impressions_response import AnalyticsImpressionsResponse
 from bitmovin_api_sdk.models.analytics_in_filter import AnalyticsInFilter
-from bitmovin_api_sdk.models.analytics_incident import AnalyticsIncident
 from bitmovin_api_sdk.models.analytics_insights_organization_settings import AnalyticsInsightsOrganizationSettings
 from bitmovin_api_sdk.models.analytics_insights_organization_settings_request import AnalyticsInsightsOrganizationSettingsRequest
 from bitmovin_api_sdk.models.analytics_interval import AnalyticsInterval
@@ -95,10 +91,8 @@ from bitmovin_api_sdk.models.analytics_query_operator import AnalyticsQueryOpera
 from bitmovin_api_sdk.models.analytics_query_request import AnalyticsQueryRequest
 from bitmovin_api_sdk.models.analytics_query_timeframe import AnalyticsQueryTimeframe
 from bitmovin_api_sdk.models.analytics_response import AnalyticsResponse
-from bitmovin_api_sdk.models.analytics_rule_metric import AnalyticsRuleMetric
 from bitmovin_api_sdk.models.analytics_stddev_query_request import AnalyticsStddevQueryRequest
 from bitmovin_api_sdk.models.analytics_sum_query_request import AnalyticsSumQueryRequest
-from bitmovin_api_sdk.models.analytics_threshold_rule_options import AnalyticsThresholdRuleOptions
 from bitmovin_api_sdk.models.analytics_variance_query_request import AnalyticsVarianceQueryRequest
 from bitmovin_api_sdk.models.analytics_video_start_failed_reason import AnalyticsVideoStartFailedReason
 from bitmovin_api_sdk.models.and_conjunction import AndConjunction
@@ -255,6 +249,7 @@ from bitmovin_api_sdk.models.domain_list import DomainList
 from bitmovin_api_sdk.models.drm import Drm
 from bitmovin_api_sdk.models.drm_type import DrmType
 from bitmovin_api_sdk.models.dts_passthrough_audio_configuration import DtsPassthroughAudioConfiguration
+from bitmovin_api_sdk.models.dvb_subtitle_configuration import DvbSubtitleConfiguration
 from bitmovin_api_sdk.models.dvb_subtitle_input_stream import DvbSubtitleInputStream
 from bitmovin_api_sdk.models.dvb_teletext_input_stream import DvbTeletextInputStream
 from bitmovin_api_sdk.models.eac3_audio_configuration import Eac3AudioConfiguration
@@ -539,6 +534,8 @@ from bitmovin_api_sdk.models.srt_statistics import SrtStatistics
 from bitmovin_api_sdk.models.standard_media_info import StandardMediaInfo
 from bitmovin_api_sdk.models.start_encoding_request import StartEncodingRequest
 from bitmovin_api_sdk.models.start_live_encoding_request import StartLiveEncodingRequest
+from bitmovin_api_sdk.models.static_ip import StaticIp
+from bitmovin_api_sdk.models.static_ip_status import StaticIpStatus
 from bitmovin_api_sdk.models.statistics import Statistics
 from bitmovin_api_sdk.models.statistics_per_label import StatisticsPerLabel
 from bitmovin_api_sdk.models.statistics_per_muxing import StatisticsPerMuxing
